@@ -28,7 +28,7 @@ mod errors;
 struct Context {
     value: String,
 }
-use miette::{IntoDiagnostic, Result};
+use miette::{GraphicalTheme, IntoDiagnostic, Result};
 
 fn main() -> Result<()> {
     if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
@@ -36,6 +36,8 @@ fn main() -> Result<()> {
             Box::new(
                 miette::MietteHandlerOpts::new()
                     .force_graphical(true)
+                    .terminal_links(false)
+                    .graphical_theme(GraphicalTheme::unicode_nocolor())
                     .build(),
             )
         }))
@@ -88,8 +90,7 @@ fn append_coauthors_to_commit_message(
     authors: &[Author],
 ) -> Result<()> {
     let _path = String::from(commit_message_path.to_string_lossy());
-    let mut commit_message =
-        CommitMessage::try_from(commit_message_path.clone()).into_diagnostic()?;
+    let mut commit_message = CommitMessage::try_from(commit_message_path.clone())?;
 
     let trailers = authors
         .iter()
@@ -117,7 +118,7 @@ fn append_relate_to_trailer_to_commit_message(
     template: Option<String>,
 ) -> Result<()> {
     let _path = String::from(commit_message_path.to_string_lossy());
-    let commit_message = CommitMessage::try_from(commit_message_path.clone()).into_diagnostic()?;
+    let commit_message = CommitMessage::try_from(commit_message_path.clone())?;
 
     let mut tt = TinyTemplate::new();
     let defaulted_template = template.unwrap_or_else(|| "{ value }".to_string());
